@@ -20,7 +20,7 @@ use POE;
 use Readonly;
 use Tk::Pane;
 
-use aliased 'POE::Kernel' => 'K';
+use constant K => $poe_kernel;
 
 Readonly my $WIDTH  => 95;
 Readonly my $HEIGHT => 145;
@@ -441,14 +441,6 @@ parameter is mandatory.
 
 
 
-=begin quiet_pod_coverage
-
-=item * K
-
-=end quiet_pod_coverage
-
-
-
 =head1 PUBLIC EVENTS
 
 The newly created POE session accepts the following events:
