@@ -19,7 +19,7 @@ use POE;
 use Tk;
 use Tk::Font;
 
-use aliased 'POE::Kernel' => 'K';
+use constant K => $poe_kernel;
 
 
 #--
@@ -278,12 +278,6 @@ parameter is mandatory.
 =back
 
 
-=begin quiet_pod_coverage
-
-=item * K
-
-=end quiet_pod_coverage
-
 
 
 =head1 PUBLIC EVENTS
