@@ -19,7 +19,7 @@ use List::Util qw{ sum };
 use POE;
 use Readonly;
 use UNIVERSAL::require;
-use aliased 'POE::Kernel' => 'K';
+use constant K => $poe_kernel;
 
 
 use base qw{ Class::Accessor::Fast };
@@ -69,7 +69,7 @@ sub new {
 #
 # my @cards = $player->cards;
 #
-# Return the list of cards (Games::Risk::Map::Card objects) currently
+# Return the list of cards (Games::Risk::Card objects) currently
 # owned by $player.
 #
 sub cards {
@@ -107,7 +107,7 @@ sub card_del {
 #
 # my @countries = $player->countries;
 #
-# Return the list of countries (Games::Risk::Map::Country objects)
+# Return the list of countries (Games::Risk::Country objects)
 # currently owned by $player.
 #
 sub countries {
@@ -251,7 +251,7 @@ The following methods are available for C<Games::Risk::Player> objects:
 
 =item my @cards = $player->cards()
 
-Return the list of cards (C<Games::Risk::Map::Card> objects) currently
+Return the list of cards (C<Games::Risk::Card> objects) currently
 owned by C<$player>.
 
 
@@ -267,7 +267,7 @@ Remove C<$card> from the set of cards owned by C<player>.
 
 =item * my @countries = $player->countries()
 
-Return the list of countries (C<Games::Risk::Map::Country> objects)
+Return the list of countries (C<Games::Risk::Country> objects)
 currently owned by C<$player>.
 
 
@@ -295,13 +295,6 @@ with the number of owned territories, as well as the number of armies.
 =back
 
 
-=begin quiet_pod_coverage
-
-=item * K
-
-=end quiet_pod_coverage
-
-
 
 =head1 SEE ALSO
 
